==> haskell-persistent-template-2.6.0-38-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-template
version: 2.6.0
id: persistent-template-2.6.0-2yf0vanhWop7CjkDWdCFeU
key: persistent-template-2.6.0-2yf0vanhWop7CjkDWdCFeU
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, non-relational, multi-backend persistence.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent-template>.
category: Database, Yesod
abi: 0d3012fd5c482a7d3220d13ce7b4a0e6
exposed: True
exposed-modules:
    Database.Persist.TH
import-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-template-2.6.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-template-2.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/persistent-template-2.6.0
hs-libraries: HSpersistent-template-2.6.0-2yf0vanhWop7CjkDWdCFeU
depends:
    aeson-1.4.3.0-BTVTAPf4Xo575Po56SJ3Aq
    aeson-compat-0.3.9-BKmAdZarZYlIYZdWoCJPxk base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1 ghc-prim-0.5.3
    http-api-data-0.4.1-6LTOYToZXHaLJ0d8ud51W1
    monad-control-1.0.2.3-JMF7teit9M6FKdrQm56I9R
    monad-logger-0.3.30-38eNwpbYILY5K51UxlCGCJ
    path-pieces-0.2.1-7jseLTOU0PkHMQiwNvt0jG
    persistent-2.9.2-2RnBZf4uO4pDQuhfps0hmV
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP template-haskell-2.14.0.0
    text-1.2.3.1 transformers-0.5.6.2
    unordered-containers-0.2.10.0-2N7l4ZvxBr3HGayD0s0P1Q
haddock-interfaces: /usr/share/doc/haskell-persistent-template/html/persistent-template.haddock
haddock-html: /usr/share/doc/haskell-persistent-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-template-2.6.0-39-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-template
version: 2.6.0
id: persistent-template-2.6.0-LvUsJMuXw1j3kv6P8ckOYk
key: persistent-template-2.6.0-LvUsJMuXw1j3kv6P8ckOYk
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, non-relational, multi-backend persistence.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent-template>.
category: Database, Yesod
abi: aeb4d3e0d050525e9191f29334a56abc
exposed: True
exposed-modules:
    Database.Persist.TH
import-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-template-2.6.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-template-2.6.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/persistent-template-2.6.0
hs-libraries: HSpersistent-template-2.6.0-LvUsJMuXw1j3kv6P8ckOYk
depends:
    aeson-1.4.3.0-BTVTAPf4Xo575Po56SJ3Aq
    aeson-compat-0.3.9-BKmAdZarZYlIYZdWoCJPxk base-4.12.0.0
    bytestring-0.10.8.2 containers-0.6.0.1 ghc-prim-0.5.3
    http-api-data-0.4.1-6LTOYToZXHaLJ0d8ud51W1
    monad-control-1.0.2.3-JMF7teit9M6FKdrQm56I9R
    monad-logger-0.3.30-DEMTYPqThZT7F1IvTj1veL
    path-pieces-0.2.1-7jseLTOU0PkHMQiwNvt0jG
    persistent-2.9.2-4GhmUaEkDKCxpLU7R96Iz
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP template-haskell-2.14.0.0
    text-1.2.3.1 transformers-0.5.6.2
    unordered-containers-0.2.10.0-2N7l4ZvxBr3HGayD0s0P1Q
haddock-interfaces: /usr/share/doc/haskell-persistent-template/html/persistent-template.haddock
haddock-html: /usr/share/doc/haskell-persistent-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
